@@ -32,4 +32,8 @@ class ClientNotConnectedError(Error):
 
 class RequestError(Error):
     """Raised when an error is recieved from the server"""
-    pass
\ No newline at end of file
+    pass
+
+class SmartDeviceRegistrationError(Error):
+    """Raised when the entity cannot be registered with"""
+    pass
